<?php
/**
 * Project:     SavantPaginate: Pagination for the Savant Template Engine
 * File:        index.php
 * Author:      Marko Martinović <marko.martinovic00 at gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * For instructions for SavantPaginate go to http://www.techytalk.info/SavantPaginate
 * For instructions for Savant go to http://www.phpsavant.com/
 *
 * Based on work from SmartyPaginate project
 * http://www.phpinsider.com/php/code/SmartyPaginate/
 *
 * @link http://www.techytalk.info/savantpaginate
 * @author Marko Martinović <marko at techytalk.info>
 * @package savantpaginate_PDO_demo
 * @version 0.1
 */

/**
 * Include configuration file
 */
$settings = parse_ini_file('settings.ini', TRUE);

/* Include classes */
require_once($_SERVER["DOCUMENT_ROOT"].'/savantpaginate_pdo_demo/savant/Savant3.php');
require_once($_SERVER["DOCUMENT_ROOT"].'/savantpaginate_pdo_demo/savant/SavantPaginate.php');

/* Include functions */
require_once('include/SavantPaginateFunctions.php');

if (!isset($_SESSION)) session_start();

/* Creating PDO object to connect to MySQL database. Database settings like
 * dbname, username, password and host are parsed from settings.ini */
$dbCon = new PDO('mysql:dbname='.$settings['database']['dbName'].';host='.$settings['database']['dbHost'], $settings['database']['dbUser'], $settings['database']['dbPass'],
                        array(
                        /* Force MySQL PDO driver to use UTF-8 for the connection */
                        PDO::MYSQL_ATTR_INIT_COMMAND => 'SET NAMES \'utf8\'',
                        /* Set the error reporting attribute */
                        PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION));

/* Creating new Savant object to use Savant templating engine. */
$tpl = new Savant3(array('template_path' => './templates'));

/* SAVANT PAGINATE STEP ONE: Initiate SavantPaginate. */
SavantPaginate::connect();

/* SAVANT PAGINATE STEP TWO (Optional): Set results limit to 20, if omitted default is 10. */
SavantPaginate::setLimit(20);

/* SAVANT PAGINATE STEP THREE (Optional):Set the default number of page groupings displayed in the middle of pagination */
SavantPaginate::setPageLimit(10);

/* SQL query string */
$sqlWhole = 'SELECT DistroName FROM LinuxDistributions';

/* SavantPaginate needs to know total number of results to be able to
 * provide pagination. Generaly for any pagination with PHP PDO we need two SQL queries.
 *  Without PDO this is generaly simpler and we need only one SQL query, but less flexible.
 */

// First SQL query to get total number of results. */
$stmt = $dbCon->prepare(replaceContentInsideDelimiters('SELECT', 'FROM', ' COUNT(*) ', $sqlWhole));
$stmt->execute();
$numResults = $stmt->fetchColumn();

/* SAVANT PAGINATE STEP FOUR: Set total number of pagination results as received from database. */
SavantPaginate::setTotal($numResults);

// Second SQL query to get paginated results.
$sqlLimited = $sqlWhole.' LIMIT '.SavantPaginate::getCurrentIndex().','.SavantPaginate::getLimit();
$stmt=$dbCon->prepare($sqlLimited);
$stmt->execute();
$distroList = $stmt->fetchAll(PDO::FETCH_ASSOC);

/* SAVANT PAGINATE STEP FIVE: This step assigns variables like first page, last page, curent URI, total count
 * and other variables needed for pagination.
 */
SavantPaginate::assign($tpl);

/* Assigns variable received from database. */
$tpl->distroList = $distroList;
$tpl->display('index.tpl.php');
?>
